@@ -8,6 +8,8 @@ from datetime import datetime
 from json import loads
 import requests
 from bs4 import BeautifulSoup
+import numpy as np
+
 
 def doomsday_clock(year):
     dc_url = "https://ja.wikipedia.org/wiki/%E4%B8%96%E7%95%8C%E7%B5%82%E6%9C%AB%E6%99%82%E8%A8%88"
@@ -104,4 +106,22 @@ def get_eq_info():
     dto = datetime.strptime(ql[0]["created_at"].split(".")[0], "%Y/%m/%d %H:%M:%S")
     retd = ql[0]["earthquake"]["hypocenter"]
     retd["datetime"] = dto
-    return retd
\ No newline at end of file
+    return retd
+
+
+coef = np.array([0.02975907, -1.47542641, 19.58163225, 21.7626419])
+
+
+def テストの点数(勉強時間):
+    """
+    勉強時間に対する，テストの点数を返す
+    100点満点，10時間で限界効用逓減によって下がって行く。
+    """
+    点数 = int(np.poly1d(coef)(勉強時間))+1
+    return 点数
+
+
+def テストの点数2(勉強時間, 集中力):
+    点数 = int(np.poly1d(coef)(勉強時間))+1-20
+    点数 = 点数*(集中力/100)+20
+    return 点数
\ No newline at end of file
